@@ -35,7 +35,7 @@
 class KConfigGroupPrivate : public QSharedData
 {
 public:
-    KConfigGroupPrivate(KConfig *owner, bool isImmutable, bool isConst, const QByteArray &name)
+    KConfigGroupPrivate(KConfig *owner, bool isImmutable, bool isConst, const QString &name)
         : mOwner(owner)
         , mName(name)
         , bImmutable(isImmutable)
@@ -46,7 +46,7 @@ public:
         }
     }
 
-    KConfigGroupPrivate(const KSharedConfigPtr &owner, const QByteArray &name)
+    KConfigGroupPrivate(const KSharedConfigPtr &owner, const QString &name)
         : sOwner(owner)
         , mOwner(sOwner.data())
         , mName(name)
@@ -58,7 +58,7 @@ public:
         }
     }
 
-    KConfigGroupPrivate(KConfigGroup *parent, bool isImmutable, bool isConst, const QByteArray &name)
+    KConfigGroupPrivate(KConfigGroup *parent, bool isImmutable, bool isConst, const QString &name)
         : sOwner(parent->d->sOwner)
         , mOwner(parent->d->mOwner)
         , mName(name)
@@ -70,7 +70,7 @@ public:
         }
     }
 
-    KConfigGroupPrivate(const KConfigGroupPrivate *other, bool isImmutable, const QByteArray &name)
+    KConfigGroupPrivate(const KConfigGroupPrivate *other, bool isImmutable, const QString &name)
         : sOwner(other->sOwner)
         , mOwner(other->mOwner)
         , mName(name)
@@ -85,13 +85,13 @@ public:
     KSharedConfig::Ptr sOwner;
     KConfig *mOwner;
     QExplicitlySharedDataPointer<KConfigGroupPrivate> mParent;
-    QByteArray mName;
+    QString mName;
 
     /* bitfield */
     const bool bImmutable : 1; // is this group immutable?
     const bool bConst : 1; // is this group read-only?
 
-    QByteArray fullName() const
+    QString fullName() const
     {
         if (!mParent) {
             return name();
@@ -99,23 +99,23 @@ public:
         return mParent->fullName(mName);
     }
 
-    QByteArray name() const
+    QString name() const
     {
         if (mName.isEmpty()) {
-            return QByteArrayLiteral("<default>");
+            return QStringLiteral("<default>");
         }
         return mName;
     }
 
-    QByteArray fullName(const QByteArray &aGroup) const
+    QString fullName(const QString &aGroup) const
     {
         if (mName.isEmpty()) {
             return aGroup;
         }
-        return fullName() + '\x1d' + aGroup;
+        return fullName() + QLatin1Char('\x1d') + aGroup;
     }
 
-    static QExplicitlySharedDataPointer<KConfigGroupPrivate> create(KConfigBase *master, const QByteArray &name, bool isImmutable, bool isConst)
+    static QExplicitlySharedDataPointer<KConfigGroupPrivate> create(KConfigBase *master, const QString &name, bool isImmutable, bool isConst)
     {
         QExplicitlySharedDataPointer<KConfigGroupPrivate> data;
         if (dynamic_cast<KConfigGroup *>(master)) {
@@ -189,11 +189,11 @@ QStringList KConfigGroupPrivate::deserializeList(const QString &data)
     return value;
 }
 
-static QVector<int> asIntList(const QByteArray &string)
+static QList<int> asIntList(const QByteArray &string)
 {
     const auto &splitString = string.split(',');
 
-    QVector<int> list;
+    QList<int> list;
     list.reserve(splitString.count());
     for (const QByteArray &s : splitString) {
         list << s.toInt();
@@ -201,11 +201,11 @@ static QVector<int> asIntList(const QByteArray &string)
     return list;
 }
 
-static QVector<qreal> asRealList(const QByteArray &string)
+static QList<qreal> asRealList(const QByteArray &string)
 {
     const auto &splitString = string.split(',');
 
-    QVector<qreal> list;
+    QList<qreal> list;
     list.reserve(splitString.count());
     for (const QByteArray &s : splitString) {
         list << s.toDouble();
@@ -216,7 +216,7 @@ static QVector<qreal> asRealList(const QByteArray &string)
 static QString errString(const char *pKey, const QByteArray &value, const QVariant &aDefault)
 {
     return QStringLiteral("\"%1\" - conversion of \"%3\" to %2 failed")
-        .arg(QString::fromLatin1(pKey), QString::fromLatin1(QVariant::typeToName(aDefault.type())), QString::fromLatin1(value));
+        .arg(QString::fromLatin1(pKey), QString::fromLatin1(aDefault.typeName()), QString::fromLatin1(value));
 }
 
 static QString formatError(int expected, int got)
@@ -227,9 +227,9 @@ static QString formatError(int expected, int got)
 QVariant KConfigGroup::convertToQVariant(const char *pKey, const QByteArray &value, const QVariant &aDefault)
 {
     // if a type handler is added here you must add a QVConversions definition
-    // to conversioncheck.h, or ConversionCheck::to_QVariant will not allow
+    // to kconfigconversioncheck_p.h, or KConfigConversionCheck::to_QVariant will not allow
     // readEntry<T> to convert to QVariant.
-    switch (static_cast<QMetaType::Type>(aDefault.type())) {
+    switch (static_cast<QMetaType::Type>(aDefault.userType())) {
     case QMetaType::UnknownType:
         return QVariant();
     case QMetaType::QString:
@@ -238,7 +238,7 @@ QVariant KConfigGroup::convertToQVariant(const char *pKey, const QByteArray &val
         // readEntry(key, QString) not readEntry(key, QVariant)
         return QString::fromUtf8(value);
     case QMetaType::QUuid:
-        return QUuid::fromString(QString::fromUtf8(value));
+        return QUuid::fromString(value);
     case QMetaType::QVariantList:
     case QMetaType::QStringList:
         return KConfigGroupPrivate::deserializeList(QString::fromUtf8(value));
@@ -258,7 +258,7 @@ QVariant KConfigGroup::convertToQVariant(const char *pKey, const QByteArray &val
     case QMetaType::LongLong:
     case QMetaType::ULongLong: {
         QVariant tmp = value;
-        if (!tmp.convert(aDefault.type())) {
+        if (!tmp.convert(aDefault.metaType())) {
             tmp = aDefault;
         }
         return tmp;
@@ -389,10 +389,6 @@ QVariant KConfigGroup::convertToQVariant(const char *pKey, const QByteArray &val
     return QVariant();
 }
 
-#ifdef Q_OS_WIN
-#include <QDir>
-#endif
-
 static bool cleanHomeDirPath(QString &path, const QString &homeDir)
 {
 #ifdef Q_OS_WIN // safer
@@ -474,35 +470,41 @@ static inline bool writeEntryGui(KConfigGroup *cg, const char *key, const QVaria
 }
 
 KConfigGroup::KConfigGroup(KConfigBase *master, const QString &_group)
-    : d(KConfigGroupPrivate::create(master, _group.toUtf8(), master->isGroupImmutable(_group), false))
-{
-}
-
-KConfigGroup::KConfigGroup(KConfigBase *master, const char *_group)
     : d(KConfigGroupPrivate::create(master, _group, master->isGroupImmutable(_group), false))
 {
 }
 
-KConfigGroup::KConfigGroup(const KConfigBase *master, const QString &_group)
-    : d(KConfigGroupPrivate::create(const_cast<KConfigBase *>(master), _group.toUtf8(), master->isGroupImmutable(_group), true))
+#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 241)
+KConfigGroup::KConfigGroup(KConfigBase *master, const char *_group)
+    : KConfigGroup(master, QString::fromUtf8(_group))
 {
 }
+#endif
 
-KConfigGroup::KConfigGroup(const KConfigBase *master, const char *_group)
+KConfigGroup::KConfigGroup(const KConfigBase *master, const QString &_group)
     : d(KConfigGroupPrivate::create(const_cast<KConfigBase *>(master), _group, master->isGroupImmutable(_group), true))
 {
 }
 
-KConfigGroup::KConfigGroup(const KSharedConfigPtr &master, const QString &_group)
-    : d(new KConfigGroupPrivate(master, _group.toUtf8()))
+#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 241)
+KConfigGroup::KConfigGroup(const KConfigBase *master, const char *_group)
+    : KConfigGroup(master, QString::fromUtf8(_group))
 {
 }
+#endif
 
-KConfigGroup::KConfigGroup(const KSharedConfigPtr &master, const char *_group)
+KConfigGroup::KConfigGroup(const KSharedConfigPtr &master, const QString &_group)
     : d(new KConfigGroupPrivate(master, _group))
 {
 }
 
+#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 241)
+KConfigGroup::KConfigGroup(const KSharedConfigPtr &master, const char *_group)
+    : KConfigGroup(master, QString::fromUtf8(_group))
+{
+}
+#endif
+
 KConfigGroup &KConfigGroup::operator=(const KConfigGroup &rhs)
 {
     d = rhs.d;
@@ -519,7 +521,7 @@ KConfigGroup::~KConfigGroup()
     d.reset();
 }
 
-KConfigGroup KConfigGroup::groupImpl(const QByteArray &aGroup)
+KConfigGroup KConfigGroup::groupImpl(const QString &aGroup)
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::groupImpl", "accessing an invalid group");
     Q_ASSERT_X(!aGroup.isEmpty(), "KConfigGroup::groupImpl", "can not have an unnamed child group");
@@ -531,7 +533,7 @@ KConfigGroup KConfigGroup::groupImpl(const QByteArray &aGroup)
     return newGroup;
 }
 
-const KConfigGroup KConfigGroup::groupImpl(const QByteArray &aGroup) const
+const KConfigGroup KConfigGroup::groupImpl(const QString &aGroup) const
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::groupImpl", "accessing an invalid group");
     Q_ASSERT_X(!aGroup.isEmpty(), "KConfigGroup::groupImpl", "can not have an unnamed child group");
@@ -552,7 +554,7 @@ KConfigGroup KConfigGroup::parent() const
     if (d->mParent) {
         parentGroup.d = d->mParent;
     } else {
-        parentGroup.d = new KConfigGroupPrivate(d->mOwner, d->mOwner->isImmutable(), d->bConst, "");
+        parentGroup.d = new KConfigGroupPrivate(d->mOwner, d->mOwner->isImmutable(), d->bConst, QString());
         // make sure we keep the refcount up on the KConfig object
         parentGroup.d->sOwner = d->sOwner;
     }
@@ -568,29 +570,11 @@ void KConfigGroup::deleteGroup(WriteConfigFlags flags)
     config()->deleteGroup(d->fullName(), flags);
 }
 
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-void KConfigGroup::changeGroup(const QString &group)
-{
-    Q_ASSERT_X(isValid(), "KConfigGroup::changeGroup", "accessing an invalid group");
-    d.detach();
-    d->mName = group.toUtf8();
-}
-#endif
-
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-void KConfigGroup::changeGroup(const char *group)
-{
-    Q_ASSERT_X(isValid(), "KConfigGroup::changeGroup", "accessing an invalid group");
-    d.detach();
-    d->mName = group;
-}
-#endif
-
 QString KConfigGroup::name() const
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::name", "accessing an invalid group");
 
-    return QString::fromUtf8(d->name());
+    return d->name();
 }
 
 bool KConfigGroup::exists() const
@@ -615,7 +599,7 @@ QMap<QString, QString> KConfigGroup::entryMap() const
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::entryMap", "accessing an invalid group");
 
-    return config()->entryMap(QString::fromUtf8(d->fullName()));
+    return config()->entryMap(d->fullName());
 }
 
 KConfig *KConfigGroup::config()
@@ -902,7 +886,7 @@ void KConfigGroup::writeEntry(const char *key, const QVariantList &list, WriteCo
     data.reserve(list.count());
 
     for (const QVariant &v : list) {
-        if (v.type() == QVariant::ByteArray) {
+        if (v.userType() == QMetaType::QByteArray) {
             data << v.toByteArray();
         } else {
             data << v.toString().toUtf8();
@@ -923,9 +907,9 @@ void KConfigGroup::writeEntry(const char *key, const QVariant &value, WriteConfi
 
     QByteArray data;
     // if a type handler is added here you must add a QVConversions definition
-    // to conversioncheck.h, or ConversionCheck::to_QVariant will not allow
+    // to kconfigconversioncheck_p.h, or KConfigConversionCheck::to_QVariant will not allow
     // writeEntry<T> to convert to QVariant.
-    switch (static_cast<QMetaType::Type>(value.type())) {
+    switch (static_cast<QMetaType::Type>(value.userType())) {
     case QMetaType::UnknownType:
         data = "";
         break;
@@ -943,7 +927,7 @@ void KConfigGroup::writeEntry(const char *key, const QVariant &value, WriteConfi
         data = value.toString().toUtf8();
         break;
     case QMetaType::QVariantList:
-        if (!value.canConvert(QMetaType::QStringList)) {
+        if (!value.canConvert<QStringList>()) {
             qCWarning(KCONFIG_CORE_LOG) << "not all types in \"" << key
                                         << "\" can convert to QString,"
                                            " information will be lost";
@@ -1126,11 +1110,6 @@ void KConfigGroup::deleteEntry(const QString &key, WriteConfigFlags flags)
     deleteEntry(key.toUtf8().constData(), flags);
 }
 
-void KConfigGroup::revertToDefault(const char *key)
-{
-    revertToDefault(key, WriteConfigFlags());
-}
-
 void KConfigGroup::revertToDefault(const char *key, WriteConfigFlags flags)
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::revertToDefault", "accessing an invalid group");
@@ -1139,11 +1118,6 @@ void KConfigGroup::revertToDefault(const char *key, WriteConfigFlags flags)
     config()->d_func()->revertEntry(d->fullName(), key, flags);
 }
 
-void KConfigGroup::revertToDefault(const QString &key)
-{
-    revertToDefault(key, WriteConfigFlags());
-}
-
 void KConfigGroup::revertToDefault(const QString &key, WriteConfigFlags flags)
 {
     revertToDefault(key.toUtf8().constData(), flags);
@@ -1215,14 +1189,14 @@ KConfigGroup::AccessMode KConfigGroup::accessMode() const
     return config()->accessMode();
 }
 
-bool KConfigGroup::hasGroupImpl(const QByteArray &b) const
+bool KConfigGroup::hasGroupImpl(const QString &b) const
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::hasGroupImpl", "accessing an invalid group");
 
     return config()->hasGroup(d->fullName(b));
 }
 
-void KConfigGroup::deleteGroupImpl(const QByteArray &b, WriteConfigFlags flags)
+void KConfigGroup::deleteGroupImpl(const QString &b, WriteConfigFlags flags)
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::deleteGroupImpl", "accessing an invalid group");
     Q_ASSERT_X(!d->bConst, "KConfigGroup::deleteGroupImpl", "deleting from a read-only group");
@@ -1230,15 +1204,15 @@ void KConfigGroup::deleteGroupImpl(const QByteArray &b, WriteConfigFlags flags)
     config()->deleteGroup(d->fullName(b), flags);
 }
 
-bool KConfigGroup::isGroupImmutableImpl(const QByteArray &b) const
+bool KConfigGroup::isGroupImmutableImpl(const QString &groupName) const
 {
     Q_ASSERT_X(isValid(), "KConfigGroup::isGroupImmutableImpl", "accessing an invalid group");
 
-    if (!hasGroupImpl(b)) { // group doesn't exist yet
+    if (!hasGroupImpl(groupName)) { // group doesn't exist yet
         return d->bImmutable; // child groups are immutable if the parent is immutable.
     }
 
-    return config()->isGroupImmutable(d->fullName(b));
+    return config()->isGroupImmutable(d->fullName(groupName));
 }
 
 void KConfigGroup::copyTo(KConfigBase *other, WriteConfigFlags pFlags) const
@@ -1276,7 +1250,7 @@ void KConfigGroup::moveValuesTo(const QList<const char *> &keys, KConfigGroup &o
     Q_ASSERT(other.isValid());
 
     for (const auto key : keys) {
-        const QByteArray groupName = name().toLocal8Bit();
+        const QString groupName = name();
         const auto entry = config()->d_ptr->lookupInternalEntry(groupName, key, KEntryMap::SearchLocalized);
 
         // Only write the entry if it is not null, if it is a global enry there is no point in moving it
@@ -1291,7 +1265,7 @@ void KConfigGroup::moveValuesTo(const QList<const char *> &keys, KConfigGroup &o
                 options |= KEntryMap::EntryExpansion;
             }
 
-            other.config()->d_ptr->setEntryData(other.name().toLocal8Bit(), key, entry.mValue, options);
+            other.config()->d_ptr->setEntryData(other.name(), key, entry.mValue, options);
         }
     }
 }
