@@ -17,10 +17,11 @@ static QString obscuredString(const QString &str)
 {
     QString result;
     const QChar *unicode = str.unicode();
-    for (int i = 0; i < str.length(); ++i)
+    for (int i = 0; i < str.length(); ++i) {
         // yes, no typo. can't encode ' ' or '!' because
         // they're the unicode BOM. stupid scrambling. stupid.
         result += (unicode[i].unicode() <= 0x21) ? unicode[i] : QChar(0x1001F - unicode[i].unicode());
+    }
 
     return result;
 }
@@ -607,10 +608,10 @@ void KCoreConfigSkeleton::ItemEnum::readConfig(KConfig *config)
     } else {
         int i = 0;
         mReference = -1;
-        QString tmp = cg.readEntry(mKey, QString()).toLower();
+        const QString entryString = cg.readEntry(mKey, QString());
         for (auto it = mChoices.cbegin(); it != mChoices.cend(); ++it, ++i) {
             QString choiceName = (*it).name;
-            if (valueForChoice(choiceName).toLower() == tmp) {
+            if (valueForChoice(choiceName).compare(entryString, Qt::CaseInsensitive) == 0) {
                 mReference = i;
                 break;
             }
@@ -644,11 +645,6 @@ QList<KCoreConfigSkeleton::ItemEnum::Choice> KCoreConfigSkeleton::ItemEnum::choi
     return mChoices;
 }
 
-QList<KCoreConfigSkeleton::ItemEnum::Choice> KCoreConfigSkeleton::ItemEnum::choices2() const
-{
-    return mChoices;
-}
-
 KCoreConfigSkeleton::ItemUInt::ItemUInt(const QString &_group, const QString &_key, quint32 &reference, quint32 defaultValue)
     : KConfigSkeletonGenericItem<quint32>(_group, _key, reference, defaultValue)
     , mHasMin(false)
@@ -873,6 +869,35 @@ QVariant KCoreConfigSkeleton::ItemRect::property() const
     return QVariant(mReference);
 }
 
+KCoreConfigSkeleton::ItemRectF::ItemRectF(const QString &_group, const QString &_key, QRectF &reference, const QRectF &defaultValue)
+    : KConfigSkeletonGenericItem<QRectF>(_group, _key, reference, defaultValue)
+{
+}
+
+void KCoreConfigSkeleton::ItemRectF::readConfig(KConfig *config)
+{
+    KConfigGroup cg = configGroup(config);
+    mReference = cg.readEntry(mKey, mDefault);
+    mLoadedValue = mReference;
+
+    readImmutability(cg);
+}
+
+void KCoreConfigSkeleton::ItemRectF::setProperty(const QVariant &p)
+{
+    mReference = p.toRectF();
+}
+
+bool KCoreConfigSkeleton::ItemRectF::isEqual(const QVariant &v) const
+{
+    return mReference == v.toRectF();
+}
+
+QVariant KCoreConfigSkeleton::ItemRectF::property() const
+{
+    return QVariant(mReference);
+}
+
 KCoreConfigSkeleton::ItemPoint::ItemPoint(const QString &_group, const QString &_key, QPoint &reference, const QPoint &defaultValue)
     : KConfigSkeletonGenericItem<QPoint>(_group, _key, reference, defaultValue)
 {
@@ -902,6 +927,35 @@ QVariant KCoreConfigSkeleton::ItemPoint::property() const
     return QVariant(mReference);
 }
 
+KCoreConfigSkeleton::ItemPointF::ItemPointF(const QString &_group, const QString &_key, QPointF &reference, const QPointF &defaultValue)
+    : KConfigSkeletonGenericItem<QPointF>(_group, _key, reference, defaultValue)
+{
+}
+
+void KCoreConfigSkeleton::ItemPointF::readConfig(KConfig *config)
+{
+    KConfigGroup cg = configGroup(config);
+    mReference = cg.readEntry(mKey, mDefault);
+    mLoadedValue = mReference;
+
+    readImmutability(cg);
+}
+
+void KCoreConfigSkeleton::ItemPointF::setProperty(const QVariant &p)
+{
+    mReference = p.toPointF();
+}
+
+bool KCoreConfigSkeleton::ItemPointF::isEqual(const QVariant &v) const
+{
+    return mReference == v.toPointF();
+}
+
+QVariant KCoreConfigSkeleton::ItemPointF::property() const
+{
+    return QVariant(mReference);
+}
+
 KCoreConfigSkeleton::ItemSize::ItemSize(const QString &_group, const QString &_key, QSize &reference, const QSize &defaultValue)
     : KConfigSkeletonGenericItem<QSize>(_group, _key, reference, defaultValue)
 {
@@ -931,6 +985,35 @@ QVariant KCoreConfigSkeleton::ItemSize::property() const
     return QVariant(mReference);
 }
 
+KCoreConfigSkeleton::ItemSizeF::ItemSizeF(const QString &_group, const QString &_key, QSizeF &reference, const QSizeF &defaultValue)
+    : KConfigSkeletonGenericItem<QSizeF>(_group, _key, reference, defaultValue)
+{
+}
+
+void KCoreConfigSkeleton::ItemSizeF::readConfig(KConfig *config)
+{
+    KConfigGroup cg = configGroup(config);
+    mReference = cg.readEntry(mKey, mDefault);
+    mLoadedValue = mReference;
+
+    readImmutability(cg);
+}
+
+void KCoreConfigSkeleton::ItemSizeF::setProperty(const QVariant &p)
+{
+    mReference = p.toSizeF();
+}
+
+bool KCoreConfigSkeleton::ItemSizeF::isEqual(const QVariant &v) const
+{
+    return mReference == v.toSizeF();
+}
+
+QVariant KCoreConfigSkeleton::ItemSizeF::property() const
+{
+    return QVariant(mReference);
+}
+
 KCoreConfigSkeleton::ItemDateTime::ItemDateTime(const QString &_group, const QString &_key, QDateTime &reference, const QDateTime &defaultValue)
     : KConfigSkeletonGenericItem<QDateTime>(_group, _key, reference, defaultValue)
 {
@@ -1037,7 +1120,7 @@ void KCoreConfigSkeleton::ItemUrlList::readConfig(KConfig *config)
         mReference = mDefault;
     } else {
         QStringList strList;
-        for (const QUrl &url : qAsConst(mDefault)) {
+        for (const QUrl &url : std::as_const(mDefault)) {
             strList.append(url.toString());
         }
         mReference.clear();
@@ -1059,7 +1142,7 @@ void KCoreConfigSkeleton::ItemUrlList::writeConfig(KConfig *config)
             cg.revertToDefault(mKey, writeFlags());
         } else {
             QStringList strList;
-            for (const QUrl &url : qAsConst(mReference)) {
+            for (const QUrl &url : std::as_const(mReference)) {
                 strList.append(url.toString());
             }
             cg.writeEntry<QStringList>(mKey, strList, writeFlags());
@@ -1182,7 +1265,7 @@ bool KCoreConfigSkeleton::useDefaults(bool b)
     }
 
     d->mUseDefaults = b;
-    for (auto *skelItem : qAsConst(d->mItems)) {
+    for (auto *skelItem : std::as_const(d->mItems)) {
         skelItem->swapDefault();
     }
 
@@ -1192,7 +1275,7 @@ bool KCoreConfigSkeleton::useDefaults(bool b)
 
 void KCoreConfigSkeleton::setDefaults()
 {
-    for (auto *skelItem : qAsConst(d->mItems)) {
+    for (auto *skelItem : std::as_const(d->mItems)) {
         skelItem->setDefault();
     }
     usrSetDefaults();
@@ -1206,7 +1289,7 @@ void KCoreConfigSkeleton::load()
 
 void KCoreConfigSkeleton::read()
 {
-    for (auto *skelItem : qAsConst(d->mItems)) {
+    for (auto *skelItem : std::as_const(d->mItems)) {
         skelItem->readConfig(d->mConfig.data());
     }
     usrRead();
@@ -1229,7 +1312,7 @@ bool KCoreConfigSkeleton::isSaveNeeded() const
 bool KCoreConfigSkeleton::save()
 {
     // qDebug();
-    for (auto *skelItem : qAsConst(d->mItems)) {
+    for (auto *skelItem : std::as_const(d->mItems)) {
         skelItem->writeConfig(d->mConfig.data());
     }
 
@@ -1257,32 +1340,12 @@ void KCoreConfigSkeleton::usrSetDefaults()
 
 void KCoreConfigSkeleton::usrRead()
 {
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-    usrReadConfig();
-#endif
 }
 
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-void KCoreConfigSkeleton::usrReadConfig()
-{
-}
-#endif
-
 bool KCoreConfigSkeleton::usrSave()
-{
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-    return usrWriteConfig();
-#else
-    return true;
-#endif
-}
-
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-bool KCoreConfigSkeleton::usrWriteConfig()
 {
     return true;
 }
-#endif
 
 void KCoreConfigSkeleton::addItem(KConfigSkeletonItem *item, const QString &name)
 {
@@ -1388,13 +1451,6 @@ KCoreConfigSkeleton::ItemLongLong *KCoreConfigSkeleton::addItemLongLong(const QS
     return item;
 }
 
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-KCoreConfigSkeleton::ItemLongLong *KCoreConfigSkeleton::addItemInt64(const QString &name, qint64 &reference, qint64 defaultValue, const QString &key)
-{
-    return addItemLongLong(name, reference, defaultValue, key);
-}
-#endif
-
 KCoreConfigSkeleton::ItemULongLong *KCoreConfigSkeleton::addItemULongLong(const QString &name, quint64 &reference, quint64 defaultValue, const QString &key)
 {
     KCoreConfigSkeleton::ItemULongLong *item;
@@ -1403,13 +1459,6 @@ KCoreConfigSkeleton::ItemULongLong *KCoreConfigSkeleton::addItemULongLong(const
     return item;
 }
 
-#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 0)
-KCoreConfigSkeleton::ItemULongLong *KCoreConfigSkeleton::addItemUInt64(const QString &name, quint64 &reference, quint64 defaultValue, const QString &key)
-{
-    return addItemULongLong(name, reference, defaultValue, key);
-}
-#endif
-
 KCoreConfigSkeleton::ItemDouble *KCoreConfigSkeleton::addItemDouble(const QString &name, double &reference, double defaultValue, const QString &key)
 {
     KCoreConfigSkeleton::ItemDouble *item;
@@ -1426,6 +1475,14 @@ KCoreConfigSkeleton::ItemRect *KCoreConfigSkeleton::addItemRect(const QString &n
     return item;
 }
 
+KCoreConfigSkeleton::ItemRectF *KCoreConfigSkeleton::addItemRectF(const QString &name, QRectF &reference, const QRectF &defaultValue, const QString &key)
+{
+    KCoreConfigSkeleton::ItemRectF *item;
+    item = new KCoreConfigSkeleton::ItemRectF(d->mCurrentGroup, key.isNull() ? name : key, reference, defaultValue);
+    addItem(item, name);
+    return item;
+}
+
 KCoreConfigSkeleton::ItemPoint *KCoreConfigSkeleton::addItemPoint(const QString &name, QPoint &reference, const QPoint &defaultValue, const QString &key)
 {
     KCoreConfigSkeleton::ItemPoint *item;
@@ -1434,6 +1491,14 @@ KCoreConfigSkeleton::ItemPoint *KCoreConfigSkeleton::addItemPoint(const QString
     return item;
 }
 
+KCoreConfigSkeleton::ItemPointF *KCoreConfigSkeleton::addItemPointF(const QString &name, QPointF &reference, const QPointF &defaultValue, const QString &key)
+{
+    KCoreConfigSkeleton::ItemPointF *item;
+    item = new KCoreConfigSkeleton::ItemPointF(d->mCurrentGroup, key.isNull() ? name : key, reference, defaultValue);
+    addItem(item, name);
+    return item;
+}
+
 KCoreConfigSkeleton::ItemSize *KCoreConfigSkeleton::addItemSize(const QString &name, QSize &reference, const QSize &defaultValue, const QString &key)
 {
     KCoreConfigSkeleton::ItemSize *item;
@@ -1442,6 +1507,14 @@ KCoreConfigSkeleton::ItemSize *KCoreConfigSkeleton::addItemSize(const QString &n
     return item;
 }
 
+KCoreConfigSkeleton::ItemSizeF *KCoreConfigSkeleton::addItemSizeF(const QString &name, QSizeF &reference, const QSizeF &defaultValue, const QString &key)
+{
+    KCoreConfigSkeleton::ItemSizeF *item;
+    item = new KCoreConfigSkeleton::ItemSizeF(d->mCurrentGroup, key.isNull() ? name : key, reference, defaultValue);
+    addItem(item, name);
+    return item;
+}
+
 KCoreConfigSkeleton::ItemDateTime *
 KCoreConfigSkeleton::addItemDateTime(const QString &name, QDateTime &reference, const QDateTime &defaultValue, const QString &key)
 {
@@ -1519,6 +1592,16 @@ QVariant KConfigCompilerSignallingItem::property() const
     return mItem->property();
 }
 
+QVariant KConfigCompilerSignallingItem::minValue() const
+{
+    return mItem->minValue();
+}
+
+QVariant KConfigCompilerSignallingItem::maxValue() const
+{
+    return mItem->maxValue();
+}
+
 void KConfigCompilerSignallingItem::readConfig(KConfig *c)
 {
     QVariant oldValue = mItem->property();
@@ -1589,3 +1672,5 @@ KConfigGroup KConfigCompilerSignallingItem::configGroup(KConfig *config) const
 {
     return mItem->configGroup(config);
 }
+
+#include "moc_kcoreconfigskeleton.cpp"
