@@ -26,7 +26,7 @@
 #include <ostream>
 #include <stdlib.h>
 
-#include "../../kconfig_version.h"
+#include "../core/kconfig_version.h"
 #include "KConfigCommonStructs.h"
 #include "KConfigHeaderGenerator.h"
 #include "KConfigParameters.h"
@@ -212,12 +212,18 @@ QString param(const QString &t)
         return QStringLiteral("const QFont &");
     } else if (type == QLatin1String("rect")) {
         return QStringLiteral("const QRect &");
+    } else if (type == QLatin1String("rectf")) {
+        return QStringLiteral("const QRectF &");
     } else if (type == QLatin1String("size")) {
         return QStringLiteral("const QSize &");
+    } else if (type == QLatin1String("sizef")) {
+        return QStringLiteral("const QSizeF &");
     } else if (type == QLatin1String("color")) {
         return QStringLiteral("const QColor &");
     } else if (type == QLatin1String("point")) {
         return QStringLiteral("const QPoint &");
+    } else if (type == QLatin1String("pointf")) {
+        return QStringLiteral("const QPointF &");
     } else if (type == QLatin1String("int")) {
         return QStringLiteral("int");
     } else if (type == QLatin1String("uint")) {
@@ -247,7 +253,7 @@ QString param(const QString &t)
     } else if (type == QLatin1String("urllist")) {
         return QStringLiteral("const QList<QUrl> &");
     } else {
-        std::cerr << "kconfig_compiler_kf5 does not support type \"" << qPrintable(type) << "\"" << std::endl;
+        std::cerr << "kconfig_compiler_kf6 does not support type \"" << qPrintable(type) << "\"" << std::endl;
         return QStringLiteral("QString"); // For now, but an assert would be better
     }
 }
@@ -266,12 +272,18 @@ QString cppType(const QString &t)
         return QStringLiteral("QFont");
     } else if (type == QLatin1String("rect")) {
         return QStringLiteral("QRect");
+    } else if (type == QLatin1String("rectf")) {
+        return QStringLiteral("QRectF");
     } else if (type == QLatin1String("size")) {
         return QStringLiteral("QSize");
+    } else if (type == QLatin1String("sizef")) {
+        return QStringLiteral("QSizeF");
     } else if (type == QLatin1String("color")) {
         return QStringLiteral("QColor");
     } else if (type == QLatin1String("point")) {
         return QStringLiteral("QPoint");
+    } else if (type == QLatin1String("pointf")) {
+        return QStringLiteral("QPointF");
     } else if (type == QLatin1String("int")) {
         return QStringLiteral("int");
     } else if (type == QLatin1String("uint")) {
@@ -301,7 +313,7 @@ QString cppType(const QString &t)
     } else if (type == QLatin1String("urllist")) {
         return QStringLiteral("QList<QUrl>");
     } else {
-        std::cerr << "kconfig_compiler_kf5 does not support type \"" << qPrintable(type) << "\"" << std::endl;
+        std::cerr << "kconfig_compiler_kf6 does not support type \"" << qPrintable(type) << "\"" << std::endl;
         return QStringLiteral("QString"); // For now, but an assert would be better
     }
 }
@@ -317,12 +329,18 @@ QString defaultValue(const QString &t)
         return QStringLiteral("QFont()");
     } else if (type == QLatin1String("rect")) {
         return QStringLiteral("QRect()");
+    } else if (type == QLatin1String("rectf")) {
+        return QStringLiteral("QRectF()");
     } else if (type == QLatin1String("size")) {
         return QStringLiteral("QSize()");
+    } else if (type == QLatin1String("sizef")) {
+        return QStringLiteral("QSizeF()");
     } else if (type == QLatin1String("color")) {
         return QStringLiteral("QColor(128, 128, 128)");
     } else if (type == QLatin1String("point")) {
         return QStringLiteral("QPoint()");
+    } else if (type == QLatin1String("pointf")) {
+        return QStringLiteral("QPointF()");
     } else if (type == QLatin1String("int")) {
         return QStringLiteral("0");
     } else if (type == QLatin1String("uint")) {
@@ -352,7 +370,7 @@ QString defaultValue(const QString &t)
     } else if (type == QLatin1String("urllist")) {
         return QStringLiteral("QList<QUrl>()");
     } else {
-        std::cerr << "Error, kconfig_compiler_kf5 does not support the \"" << qPrintable(type) << "\" type!" << std::endl;
+        std::cerr << "Error, kconfig_compiler_kf6 does not support the \"" << qPrintable(type) << "\" type!" << std::endl;
         return QStringLiteral("QString"); // For now, but an assert would be better
     }
 }
